@@ -6,7 +6,6 @@ use {
     anyhow::{anyhow, Result},
     once_cell::sync::Lazy,
     std::{
-        convert::TryFrom,
         fmt::{Display, Formatter},
         path::PathBuf,
     },
@@ -23,6 +22,7 @@ use {crate::find_vswhere, std::collections::BTreeMap};
 
 pub static VC_REDIST_X86: Lazy<RemoteContent> = Lazy::new(|| {
     RemoteContent {
+        name: "VC_REDIST_X86".to_string(),
         url: "https://download.visualstudio.microsoft.com/download/pr/888b4c07-c602-499a-9efb-411188496ce7/F3A86393234099BEDD558FD35AB538A6E4D9D4F99AD5ADFA13F603D4FF8A42DC/VC_redist.x86.exe".to_string(),
         sha256: "f3a86393234099bedd558fd35ab538a6e4d9d4f99ad5adfa13f603d4ff8a42dc".to_string(),
     }
@@ -30,6 +30,7 @@ pub static VC_REDIST_X86: Lazy<RemoteContent> = Lazy::new(|| {
 
 pub static VC_REDIST_X64: Lazy<RemoteContent> = Lazy::new(|| {
     RemoteContent {
+        name: "VC_REDIST_X64".to_string(),
         url: "https://download.visualstudio.microsoft.com/download/pr/36e45907-8554-4390-ba70-9f6306924167/97CC5066EB3C7246CF89B735AE0F5A5304A7EE33DC087D65D9DFF3A1A73FE803/VC_redist.x64.exe".to_string(),
         sha256: "97cc5066eb3c7246cf89b735ae0f5a5304a7ee33dc087d65d9dff3a1a73fe803".to_string(),
     }
@@ -37,6 +38,7 @@ pub static VC_REDIST_X64: Lazy<RemoteContent> = Lazy::new(|| {
 
 pub static VC_REDIST_ARM64: Lazy<RemoteContent> = Lazy::new(|| {
     RemoteContent {
+        name: "VC_REDIST_ARM64".to_string(),
         url: "https://download.visualstudio.microsoft.com/download/pr/888b4c07-c602-499a-9efb-411188496ce7/B76EF09CD8B114148EADDDFC6846EF178E6B7797F590191E22CEE29A20B51692/VC_redist.arm64.exe".to_string(),
         sha256: "b76ef09cd8b114148eadddfc6846ef178e6b7797f590191e22cee29a20b51692".to_string(),
     }
@@ -145,7 +147,7 @@ pub fn find_visual_cpp_redistributable(
             .entry(semver::Version::parse(
                 version_path.as_os_str().to_string_lossy().as_ref(),
             )?)
-            .or_insert(vec![])
+            .or_insert_with(Vec::new)
             .push(path);
     }
 
